==> bibledit-web-1.5.zip: bibledit-web/help/scripts/shortcuts.php <==
<?php
/*
Copyright (©) 2003-2013 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/
?>
<h1><?php echo gettext ("Keyboard shortcuts") ?></h1>
<table>
<tr><td>Ctrl-G</td><td><a href="navigation.php"><?php echo gettext ("Display a text entry, enter a new passage to go to, and press Enter.") ?></a></td></tr>
<tr><td>Escape</td><td><a href="navigation.php"><?php echo gettext ("Cancel any navigation or style operation.") ?></a></td></tr>
<tr><td>Alt-Left Arrow</td><td><a href="navigation.php"><?php echo gettext ("Go back in the navigation history.") ?></a></td></tr>
<tr><td>Alt-Right Arrow</td><td><a href="navigation.php"><?php echo gettext ("Go forward in the navigation history.") ?></a></td></tr>
<tr><td>Alt-Down Arrow</td><td><a href="navigation.php"><?php echo gettext ("Navigate to the next verse.") ?></a></td></tr>
<tr><td>Alt-Up Arrow</td><td><a href="navigation.php"><?php echo gettext ("Navigate to the previous verse.") ?></a></td></tr>
<tr><td>Ctrl-S</td><td><?php echo gettext ("Open the styles from the Bible editor.") ?></td></tr>
</table>

==> bibledit-web-1.6.zip: bibledit-web/help/scripts/shortcuts.php <==
<?php
/*
Copyright (©) 2003-2014 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/
?>
<h1><?php echo gettext ("Keyboard shortcuts") ?></h1>
<table>
<tr><td>Ctrl-G</td><td><a href="navigation.php"><?php echo gettext ("Focus the entry, enter the passage where to go, and press Enter.") ?></a></td></tr>
<tr><td>Escape</td><td><a href="navigation.php"><?php echo gettext ("Cancel any navigation or style operation.") ?></a></td></tr>
<tr><td>Alt-Left Arrow</td><td><a href="navigation.php"><?php echo gettext ("Go back in the navigation history.") ?></a></td></tr>
<tr><td>Alt-Right Arrow</td><td><a href="navigation.php"><?php echo gettext ("Go forward in the navigation history.") ?></a></td></tr>
<tr><td>Alt-Down Arrow</td><td><a href="navigation.php"><?php echo gettext ("Navigate to the next verse.") ?></a></td></tr>
<tr><td>Alt-Up Arrow</td><td><a href="navigation.php"><?php echo gettext ("Navigate to the previous verse.") ?></a></td></tr>
<tr><td>Ctrl-S</td><td><?php echo gettext ("Open the styles from the Bible editor.") ?></td></tr>
</table>
